# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector.api.chat_api_api import ChatApiApi  # noqa: E501


class TestChatApiApi(unittest.IsolatedAsyncioTestCase):
    """ChatApiApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatApiApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_bot_chat_by_topic_slug(self) -> None:
        """Test case for chat_api_bot_chat_by_topic_slug

        Bot Chat By Topic Slug  # noqa: E501
        """
        pass

    async def test_chat_api_bot_chat_chat_get(self) -> None:
        """Test case for chat_api_bot_chat_chat_get

        Bot Chat Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_bot_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_chat_get_or_create

        Bot Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_bot_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_chat_topics_list

        Bot Chat Topics List  # noqa: E501
        """
        pass

    async def test_chat_api_bot_landing_chat_get(self) -> None:
        """Test case for chat_api_bot_landing_chat_get

        Bot Landing Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_bot_landing_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_landing_chat_get_or_create

        Bot Landing Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_bot_landing_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_landing_primary_chat_topics_list

        Bot Landing Primary Chat Topics List  # noqa: E501
        """
        pass

    async def test_chat_api_bot_portal_chat_get(self) -> None:
        """Test case for chat_api_bot_portal_chat_get

        Bot Portal Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_bot_portal_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_portal_chat_get_or_create

        Bot Portal Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_bot_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_primary_chat_topics_list

        Bot Primary Chat Topics List  # noqa: E501
        """
        pass

    async def test_chat_api_bot_shared_chat_get(self) -> None:
        """Test case for chat_api_bot_shared_chat_get

        Bot Shared Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_bot_shared_chat_get_or_create(self) -> None:
        """Test case for chat_api_bot_shared_chat_get_or_create

        Bot Shared Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_bot_shared_primary_chat_topics_list(self) -> None:
        """Test case for chat_api_bot_shared_primary_chat_topics_list

        Bot Shared Primary Chat Topics List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_ai_usage_insert(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert

        Chat Ai Usage Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_ai_usage_insert_v2(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert_v2

        Chat Ai Usage Insert V2  # noqa: E501
        """
        pass

    async def test_chat_api_chat_delete(self) -> None:
        """Test case for chat_api_chat_delete

        Chat Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_get(self) -> None:
        """Test case for chat_api_chat_get

        Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_join(self) -> None:
        """Test case for chat_api_chat_join

        Chat Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_leave(self) -> None:
        """Test case for chat_api_chat_leave

        Chat Leave  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mark_as_read(self) -> None:
        """Test case for chat_api_chat_mark_as_read

        Chat Mark As Read  # noqa: E501
        """
        pass

    async def test_chat_api_chat_member_ban(self) -> None:
        """Test case for chat_api_chat_member_ban

        Chat Member Ban  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_list(self) -> None:
        """Test case for chat_api_chat_members_list

        Chat Members List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_update(self) -> None:
        """Test case for chat_api_chat_members_update

        Chat Members Update  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_delete(self) -> None:
        """Test case for chat_api_chat_message_delete

        Chat Message Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_get(self) -> None:
        """Test case for chat_api_chat_message_get

        Chat Message Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_add(self) -> None:
        """Test case for chat_api_chat_messages_add

        Chat Messages Add  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_insert(self) -> None:
        """Test case for chat_api_chat_messages_insert

        Chat Messages Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_list(self) -> None:
        """Test case for chat_api_chat_messages_list

        Chat Messages List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mute(self) -> None:
        """Test case for chat_api_chat_mute

        Chat Mute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_patch(self) -> None:
        """Test case for chat_api_chat_patch

        Chat Patch  # noqa: E501
        """
        pass

    async def test_chat_api_chat_private_join(self) -> None:
        """Test case for chat_api_chat_private_join

        Chat Private Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_feedback_add(self) -> None:
        """Test case for chat_api_chat_session_feedback_add

        Chat Session Feedback Add  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_get(self) -> None:
        """Test case for chat_api_chat_session_get

        Chat Session Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_list_portal(self) -> None:
        """Test case for chat_api_chat_session_list_portal

        Chat Session List Portal  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_portal_count(self) -> None:
        """Test case for chat_api_chat_session_portal_count

        Chat Session Portal Count  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_start(self) -> None:
        """Test case for chat_api_chat_session_start

        Chat Session Start  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_stop(self) -> None:
        """Test case for chat_api_chat_session_stop

        Chat Session Stop  # noqa: E501
        """
        pass

    async def test_chat_api_chat_unmute(self) -> None:
        """Test case for chat_api_chat_unmute

        Chat Unmute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_update(self) -> None:
        """Test case for chat_api_chat_update

        Chat Update  # noqa: E501
        """
        pass

    async def test_chat_api_chats_add(self) -> None:
        """Test case for chat_api_chats_add

        Chats Add  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list(self) -> None:
        """Test case for chat_api_chats_list

        Chats List  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list_available(self) -> None:
        """Test case for chat_api_chats_list_available

        Chats List Available  # noqa: E501
        """
        pass

    async def test_chat_api_contact_chat_get(self) -> None:
        """Test case for chat_api_contact_chat_get

        Contact Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_contact_chat_get_or_create(self) -> None:
        """Test case for chat_api_contact_chat_get_or_create

        Contact Chat Get Or Create  # noqa: E501
        """
        pass

    async def test_chat_api_contact_get(self) -> None:
        """Test case for chat_api_contact_get

        Contact Get  # noqa: E501
        """
        pass

    async def test_chat_api_contacts_list(self) -> None:
        """Test case for chat_api_contacts_list

        Contacts List  # noqa: E501
        """
        pass

    async def test_chat_api_feedback_count(self) -> None:
        """Test case for chat_api_feedback_count

        Feedback Count  # noqa: E501
        """
        pass

    async def test_chat_api_feedback_list(self) -> None:
        """Test case for chat_api_feedback_list

        Feedback List  # noqa: E501
        """
        pass

    async def test_chat_api_get_total_unread_messages(self) -> None:
        """Test case for chat_api_get_total_unread_messages

        Get Total Unread Messages  # noqa: E501
        """
        pass

    async def test_chat_api_settings_get(self) -> None:
        """Test case for chat_api_settings_get

        Settings Get  # noqa: E501
        """
        pass

    async def test_chat_api_settings_set(self) -> None:
        """Test case for chat_api_settings_set

        Settings Set  # noqa: E501
        """
        pass

    async def test_chat_api_stop_agent_run(self) -> None:
        """Test case for chat_api_stop_agent_run

        Stop Agent Run  # noqa: E501
        """
        pass

    async def test_chat_api_wipe_bots_from_cache(self) -> None:
        """Test case for chat_api_wipe_bots_from_cache

        Wipe Bots From Cache  # noqa: E501
        """
        pass

    async def test_chat_api_wipe_portal_community_settings_from_cache(self) -> None:
        """Test case for chat_api_wipe_portal_community_settings_from_cache

        Wipe Portal Community Settings From Cache  # noqa: E501
        """
        pass

    async def test_chat_api_wipe_portal_members_from_cache(self) -> None:
        """Test case for chat_api_wipe_portal_members_from_cache

        Wipe Portal Members From Cache  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
